describe Establish do
  describe Establish::App do
    let (:apple_id) { 284882215 }
    let (:app_identifier) { 'com.facebook.Facebook' }

    describe "#initialize" do
      it "automatically fetches the app identifier, if only Apple ID is given" do
        app = Establish::App.new(apple_id)

        app.app_identifier.should eq(app_identifier)
        app.apple_id.should eq(apple_id)
      end

      it "lets me create an app using an Apple ID and app identifier" do
        app = Establish::App.new(apple_id, app_identifier)

        app.app_identifier.should eq(app_identifier)
        app.apple_id.should eq(apple_id)
      end

      it "lets me create an app without any information given (yet)" do
        Establish::App.new.app_identifier.should eq(nil)
      end
    end


    describe "Accessing App Metadata", felix: true do
      before do
        @app = Establish::App.new(794902327, 'net.sunapps.1')
      end

      describe "#set_metadata_directory" do

        it "throws an exception when updating the location after accessing metadata" do
          @app.metadata
          except {
            @app.set_metadata_directory("something")
          }.to raise_error("Can not change metadata directory after accessing metadata of an app")
        end

        it "let's the user modify the download directory" do
          @app.get_metadata_directory.should eq('./')

          alternative = '/tmp/something'
          @app.set_metadata_directory(alternative)

          @app.get_metadata_directory.should eq(alternative)
        end

      end

      describe "#upload_metadata!" do
        it "throws an exception when metadata was not yet downloaded" do
          except {
            @app.upload_metadata!
          }.to raise_error("You first have to modify the metadata using app.metadata.setDescription")
        end
      end
    end
  end
end
